pyxmpp.jabber.muccore.MucStanzaExt

Package pyxmpp :: Package jabber :: Module muccore :: Class MucStanzaExt |
[hide private]

# Class MucStanzaExt

source code

Known Subclasses:
  - MucIq
  - , MucPresence

Base class for MUC specific stanza extensions. Used together with one of stanza classes (Iq, Message or Presence).

Instance Methods | [hide private]
__init__(self) Initialize a MucStanzaExt derived object. | source code
MucX or MucUserX or MucAdminQuery or MucOwnerX |
get_muc_child(self) Get the MUC specific payload element. | source code
clear_muc_child(self) Remove the MUC specific stanza payload element. | source code
MucUserX |
make_muc_userinfo(self) Create <x xmlns="...muc#user"/> element in the stanza. | source code
MucAdminQuery |
make_muc_admin_quey(self) Create <query xmlns="...muc#admin"/> element in the stanza. | source code
muc_free(self) Free MUC specific data. | source code

Method Details | [hide private]

### get_muc_child(self) | source code
Get the MUC specific payload element. Returns: MucX or MucUserX or MucAdminQuery or MucOwnerX the object describing the stanza payload in MUC namespace.

### make_muc_userinfo(self) | source code
Create <x xmlns="...muc#user"/> element in the stanza. Returns: MucUserX the element created.

### make_muc_admin_quey(self) | source code
Create <query xmlns="...muc#admin"/> element in the stanza. Returns: MucAdminQuery the element created.